diff src/protocols/oscar/buddylist.c @ 5836:09f7f23dc83a

[gaim-migrate @ 6267] I think I've fixed the negative online time for real, now. Or, at least reduced the frequency of it happening. Also added the ability to see iChat's "available" messages. Sean, I ended up changing more than I thought I would have to, but that's partially because I like to change things a lot. If it conflicts or whatever feel free to back it out and I can re-patch it back in when you're done with your stuff. committer: Tailor Script <tailor@pidgin.im>
author Mark Doliner <mark@kingant.net>
date Thu, 12 Jun 2003 03:27:58 +0000
parents 0b64f386a7b8
children 04dc7fe68889
line wrap: on
line diff
--- a/src/protocols/oscar/buddylist.c	Wed Jun 11 22:46:38 2003 +0000
+++ b/src/protocols/oscar/buddylist.c	Thu Jun 12 03:27:58 2003 +0000
@@ -232,11 +232,11 @@
  * Subtypes 0x000b and 0x000c - Change in buddy status
  *
  * Oncoming Buddy notifications contain a subset of the
  * user information structure.  Its close enough to run
  * through aim_extractuserinfo() however.
  *
  * Although the offgoing notification contains no information,
- * it is still in a format parsable by extractuserinfo.
+ * it is still in a format parsable by aim_info_extract().
  *
  */
 static int buddychange(aim_session_t *sess, aim_module_t *mod, aim_frame_t *rx, aim_modsnac_t *snac, aim_bstream_t *bs)
@@ -245,11 +245,13 @@
 	aim_userinfo_t userinfo;
 	aim_rxcallback_t userfunc;
 
-	aim_extractuserinfo(sess, bs, &userinfo);
+	aim_info_extract(sess, bs, &userinfo);
 
 	if ((userfunc = aim_callhandler(sess, rx->conn, snac->family, snac->subtype)))
 		ret = userfunc(sess, rx, &userinfo);
 
+	aim_info_free(&userinfo);
+
 	return ret;
 }
@@ -232,11 +232,11 @@
  *
  * Oncoming Buddy notifications contain a subset of the
- * user information structure.  Its close enough to run
- * through aim_extractuserinfo() however.
+ * user information structure.  It's close enough to run
+ * through aim_info_extract() however.
  *
  * Although the offgoing notification contains no information,